puffbird.FrameEngine
====================

.. currentmodule:: puffbird

.. autoclass:: FrameEngine

   


..
   HACK -- the point here is that we don't want this to appear in the output, but the autosummary should still generate the pages.
   .. autosummary::
      :toctree:
      
      FrameEngine.apply
      FrameEngine.col_apply
      FrameEngine.drop
      FrameEngine.expand_col
      FrameEngine.multid_pivot
      FrameEngine.rename
      FrameEngine.to_long
      FrameEngine.to_puffy




   


..
   HACK -- the point here is that we don't want this to appear in the output, but the autosummary should still generate the pages.
   .. autosummary::
      :toctree:
      
      FrameEngine.cols
      FrameEngine.cols_rename
      FrameEngine.datacols
      FrameEngine.datacols_rename
      FrameEngine.indexcols
      FrameEngine.indexcols_rename
      FrameEngine.table


